#!/bin/sh
#
# source: http://dbus.freedesktop.org/releases/dbus/dbus-1.2.12.tar.gz
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------Set Some Variables

soft='dbus'
softversion='1.2.12'
packageversion='54.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------Set correct permissions

cd $src

chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu" \
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --mandir=/usr/man \
  --enable-static=no \
  --with-system-pid-file=/var/run/dbus/dbus.pid \
  --with-system-socket=/var/run/dbus/system_bus_socket \
  --with-init-scripts=slackware

make -j2
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null 
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

find $dest/usr/man -type f -exec gzip -9 {} \;

# Install a custom init script for dbus - the included one is not good for us

rm $dest/etc/rc.d/*
cat > $dest/etc/rc.d/rc.messagebus.new << 'EOR'
#!/bin/sh
#
# messagebus:   The D-BUS systemwide message bus
#
# description:  This is a daemon which broadcasts notifications of system events \
#               and other messages. See http://www.freedesktop.org/software/dbus/
#
# processname: dbus-daemon
# pidfile: /var/run/dbus/pid

# This is a modified version of the rc.messagebus script distributed with the
# dbus sources.  Thanks to Don Tanner of the GWare <http://gware.org> Project
# for most of the work involved      --Robby Workman <rworkman@slackware.com>
#
# this is unmodified rc.messagebus Robby Workman Slackware script.
#


PIDFILE=/var/run/dbus/dbus.pid

start() {
  if ! ps axc | grep -w dbus-daemon ; then
    rm -f $(dirname $PIDFILE)/*
    if [ -x /usr/bin/dbus-uuidgen -a -x /usr/bin/dbus-daemon ] ; then
      echo "Starting system message bus:  /usr/bin/dbus-uuidgen --ensure ; /usr/bin/dbus-daemon --system"
      /usr/bin/dbus-uuidgen --ensure
      /usr/bin/dbus-daemon --system 1> /dev/null
    fi
  fi
}

stop() {
  if [ -e "$PIDFILE" ]; then
    echo "Stopping system message bus..."
    pid=$(cat $PIDFILE)
    kill $pid 1> /dev/null 2> /dev/null
    # Just in case:
    killall dbus-daemon 1> /dev/null 2> /dev/null
    rm -f $PIDFILE
  fi
}

reload() {
  echo "Reloading system message bus configuration..."
  if [ -e "$PIDFILE" ]; then
    pid=$(cat $PIDFILE)
    kill -HUP $pid
  else
    killall -HUP dbus-daemon
  fi
}

status() {
  if ps axc | grep -wq dbus-daemon 2>/dev/null ; then
    echo "dbus-daemon is running."
  else
    echo "dbus is stopped."
  fi
}

# See how we were called.
case "$1" in
  start)
    start
    ;;
  stop)
    stop
    ;;
  restart)
    stop
    start
    ;;
  reload)
    reload
    ;;
  status)
    status
    ;;
  *)
    echo $"Usage: $0 {start|stop|restart|reload|status}"
    ;;
esac
EOR

chmod 0755 $dest/etc/rc.d/rc.messagebus.new

# Let's not clobber existing config files

mv $dest/etc/dbus-1/session.conf $dest/etc/dbus-1/session.conf.new
rm $dest/etc/dbus-1/system.conf
cat $buildir/system.conf > $dest/etc/dbus-1/system.conf.new

# Fix some directory ownership

chown messagebus $dest/var/lib/dbus

#-------------------Prepare the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING HACKING INSTALL README $dest/usr/doc/$soft-$softversion
find $dest/usr/doc/$soft-$softversion -type f -exec chmod 644 {} \;

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

    |-----handy-ruler---------------------------------------------------------|
dbus: dbus - is a message bus system
dbus:
dbus: D-Bus is a message bus system, a simple way for applications to talk to
dbus: one another. In addition to interprocess communication, D-Bus helps
dbus: coordinate process lifecycle; it makes it simple and reliable to code a
dbus: "single instance" application or daemon, and to launch applications and
dbus: daemons on demand when their services are needed.
dbus:
dbus:
dbus:
dbus:
EODESC

#----------------- make all needed stuff in doinst

cat > $dest/install/doinst.sh << 'EOD'
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

# Keep same perms on rc.messagebus.new:
if [ -e etc/rc.d/rc.messagebus ]; then
  cp -a etc/rc.d/rc.messagebus etc/rc.d/rc.messagebus.new.incoming
  cat etc/rc.d/rc.messagebus.new > etc/rc.d/rc.messagebus.new.incoming
  mv etc/rc.d/rc.messagebus.new.incoming etc/rc.d/rc.messagebus.new
fi

config etc/dbus-1/session.conf.new
config etc/dbus-1/system.conf.new
config etc/rc.d/rc.messagebus.new
EOD

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5